@@ -2,16 +2,16 @@
 Kitsu.io API Wrapper
 ~~~~~~~~~~~~~~~~~~~
 A simple async python wrapper for the Kitsu.io API.
-:copyright: (c) 2021-present MrArkon
+:copyright: (c) 2021-2022 MrArkon, 2022-present Dymattic
 :license: MIT, see LICENSE.txt for more details.
 
 """
 
-__title__   = "kitsu"
-__version__ = "1.0.0"
-__author__  = "MrArkon"
+__title__   = "kitsu_extended"
+__version__ = "1.0.2"
+__author__  = "Dymattic"
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2021-present MrArkon'
+__copyright__ = 'Copyright 2021-2022 MrArkon, 2022-present Dymattic'
 
 __all__  = ('Client', 'HTTPException', 'BadRequest', 'NotFound', 'Anime', 'Manga')
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
